@@ -5,13 +5,11 @@
 //! Utilities for configuring a Python interpreter.
 
 use {
-    super::config::OxidizedPythonInterpreterConfig,
+    super::config::ResolvedOxidizedPythonInterpreterConfig,
     libc::{c_int, size_t, wchar_t},
     python3_sys as pyffi,
     python_packaging::{
-        interpreter::{
-            CheckHashPYCsMode, PythonInterpreterConfig, PythonInterpreterProfile, PythonRunMode,
-        },
+        interpreter::{CheckHashPYCsMode, PythonInterpreterConfig, PythonInterpreterProfile},
         resource::BytecodeOptimizationLevel,
     },
     std::convert::TryInto,
@@ -235,23 +233,12 @@ fn set_legacy_windows_stdio(config: &mut pyffi::PyConfig, value: bool) {
     config.legacy_windows_stdio = if value { 1 } else { 0 };
 }
 
-impl<'a> OxidizedPythonInterpreterConfig<'a> {
+impl<'a> ResolvedOxidizedPythonInterpreterConfig<'a> {
     /// Whether the run configuration should execute via Py_RunMain().
     pub(crate) fn uses_py_runmain(&self) -> bool {
-        if self.interpreter_config.run_command.is_some()
+        self.interpreter_config.run_command.is_some()
             || self.interpreter_config.run_filename.is_some()
             || self.interpreter_config.run_module.is_some()
-        {
-            true
-        } else {
-            match &self.run {
-                PythonRunMode::Eval { .. } => true,
-                PythonRunMode::File { .. } => true,
-                PythonRunMode::Module { .. } => true,
-                PythonRunMode::Repl => true,
-                PythonRunMode::None => false,
-            }
-        }
     }
 }
 
@@ -578,7 +565,7 @@ pub fn python_interpreter_config_to_py_config(
     Ok(config)
 }
 
-impl<'a> TryInto<pyffi::PyConfig> for &'a OxidizedPythonInterpreterConfig<'a> {
+impl<'a> TryInto<pyffi::PyConfig> for &'a ResolvedOxidizedPythonInterpreterConfig<'a> {
     type Error = String;
 
     fn try_into(self) -> Result<pyffi::PyConfig, Self::Error> {
@@ -613,41 +600,6 @@ impl<'a> TryInto<pyffi::PyConfig> for &'a OxidizedPythonInterpreterConfig<'a> {
             }
         }
 
-        match &self.run {
-            PythonRunMode::None => {}
-            PythonRunMode::Repl => {}
-            PythonRunMode::Eval { code } => {
-                if self.interpreter_config.run_command.is_none() {
-                    set_config_string_from_str(
-                        &config,
-                        &config.run_command,
-                        code,
-                        "setting run_command",
-                    )?;
-                }
-            }
-            PythonRunMode::File { path } => {
-                if self.interpreter_config.run_filename.is_none() {
-                    set_config_string_from_path(
-                        &config,
-                        &config.run_filename,
-                        path,
-                        "setting run_filename",
-                    )?;
-                }
-            }
-            PythonRunMode::Module { module } => {
-                if self.interpreter_config.run_module.is_none() {
-                    set_config_string_from_str(
-                        &config,
-                        &config.run_module,
-                        module,
-                        "setting run_module",
-                    )?;
-                }
-            }
-        }
-
         Ok(config)
     }
 }
