@@ -90,15 +90,16 @@ rusty_fork_test! {
         config.interpreter_config.parse_argv = Some(false);
         config.interpreter_config.module_search_paths = Some(vec![PathBuf::from("$ORIGIN/lib")]);
 
+        let config = config.resolve().unwrap();
+
         let origin = std::env::current_exe()
             .unwrap()
             .parent()
             .unwrap()
             .to_path_buf();
 
-        let paths = config.resolve_module_search_paths().unwrap();
         assert_eq!(
-            paths,
+            &config.interpreter_config.module_search_paths,
             &Some(vec![PathBuf::from(format!("{}/lib", origin.display()))])
         );
 
@@ -208,7 +209,7 @@ rusty_fork_test! {
         let value_raw = argvb.get_item(py, 0);
         let value_bytes = value_raw.cast_as::<PyBytes>(py).unwrap();
         assert_eq!(
-            value_bytes.data(py),
+            value_bytes.data(py).to_vec(),
             if cfg!(windows) {
                 // UTF-16.
                 b"\x4e\x2d\x65\x87".to_vec()
@@ -364,4 +365,23 @@ rusty_fork_test! {
             b"\xe4\xb8\xad\xe6\x96\x87"
         });
     }
+
+    #[test]
+    fn test_tcl_library_origin() {
+        let mut config = OxidizedPythonInterpreterConfig::default();
+        // Otherwise the Rust arguments are interpreted as Python arguments.
+        config.interpreter_config.parse_argv = Some(false);
+        config.tcl_library = Some(PathBuf::from("$ORIGIN").join("lib").join("tcl8.6"));
+
+        let config = config.resolve().unwrap();
+
+        let origin = std::env::current_exe()
+            .unwrap()
+            .parent()
+            .unwrap()
+            .to_path_buf();
+
+
+        assert_eq!(config.tcl_library, Some(origin.join("lib").join("tcl8.6")));
+    }
 }
